<?php
/*****************************************************************************\
*									      *
*   File name       session_cookie.inc.php					      *
*									      *
*   Description	    Manage sessions via cookies stored in the client browser. *
*									      *
*   URL arguments   UserName		The user name			      *
*		    UserPassword	His password			      *
*		    TargetURL		Where we were going before login.     *
*									      *
*   Notes	    To use this session mechanism, set in config.inc.php:     *
*			$auth["session"]  = "cookie";			      *
*									      *
*   History								      *
*    2003/11/09 JFL Created this file					      *
*    Remaining history in ChangeLog and CVS logs                              *
*									      *
\*****************************************************************************/

// $Id: session_cookie.inc.php,v 1.9.2.4 2007/02/13 12:53:34 jberanek Exp $

if (isset($cookie_path_override))
{
  $cookie_path = $cookie_path_override;
}
else
{
  $cookie_path = $PHP_SELF;
  $cookie_path = ereg_replace('[^/]*$', '', $cookie_path);
}

/*
  Target of the form with sets the URL argument "Action=SetName".
  Will eventually return to URL argument "TargetURL=whatever".
*/
if (isset($Action) && ($Action == "SetName"))
{
    // Avoid errors with error level ALL
    if ( !isset( $NewUserName ) )
    {
    	$NewUserName = "";
    }
    /* First make sure the password is valid */
    if ($NewUserName == "") {
        // Delete cookie

        setcookie("UserName", '', time()-42000, $cookie_path);
    } else {
        $NewUserName = unslashes($NewUserName);
        $NewPassword = unslashes($NewPassword);

        if (!authValidateUser($NewUserName, $NewUserPassword))
        {
            printLoginForm($TargetURL,2);
            exit();
        }
        else
        {
            $UserName     = $NewUserName;
            $UserPassword = $NewUserPassword;
        }

        setcookie("UserName", $UserName,strtotime("+1 month"), $cookie_path);
    }
    header ("Location: $TargetURL"); /* Redirect browser to initial page */
    /* Note HTTP 1.1 mandates an absolute URL. Most modern browsers support relative URLs,
        which allows to work around problems with DNS inconsistencies in the server name.
        Anyway, if the browser cannot redirect automatically, the manual link below will work. */
	$layout=new Smarty;
	init_header(&$layout);
    $layout->assign("TargetURL",htmlspecialchars($TargetURL));
    $layout->display("redirect.html");
    exit();
}

/*
  Display the login form. Used by two routines below.
  Will eventually return to $TargetURL.
*/
function printLoginForm($TargetURL,$whyprints=0)
{
    global $PHP_SELF;
    $layout=new Smarty;
    init_header($layout);
    $layout->assign("TargetURL",$TargetURL);
    $layout->assign("whyprints",$whyprints);
    $layout->display("loginform.html");
}

/*
 Target of the form with sets the URL argument "Action=QueryName".
 Will eventually return to URL argument "TargetURL=whatever".
*/
if (isset($Action) && ($Action == "QueryName"))
{	
    printLoginForm($TargetURL);
    exit();
}

/* authGet()
 * 
 * Request the user name/password
 * 
 * Returns: Nothing
 */
function authGet()
{
    global $PHP_SELF, $QUERY_STRING;

    $TargetURL = basename($PHP_SELF);
    if (isset($QUERY_STRING)) $TargetURL = $TargetURL . "?" . $QUERY_STRING;
    printLoginForm($TargetURL,1);

    exit();
}

function getUserName()
{
    if (!empty($_COOKIE) && isset($_COOKIE["UserName"]))
    {
	return $_COOKIE["UserName"];
    }
    else
    {
        global $HTTP_COOKIE_VARS;
	if (!empty($HTTP_COOKIE_VARS) && isset($HTTP_COOKIE_VARS["UserName"]))
	    return $HTTP_COOKIE_VARS["UserName"];
    }
}

// Print the logon entry on the top banner.
function PrintLogonBox()
{//must be defined to print the logon box
}

?>
